"""
@author Aumit Leon
Convert Markdown documents to HTML
Uses the mistune library markdown parser: https://github.com/lepture/mistune (Copyright (c) 2014, Hsiaoming Yang)
License information for use of mistune library: https://github.com/lepture/mistune/blob/master/LICENSE
"""

import re
import argparse
import mistune
from bs4 import BeautifulSoup as bs


def main():
    # Collect arguments
    parser = argparse.ArgumentParser(description="Convert Markdown File to HTML file")
    parser.add_argument(
        "--input", "-i", type=str, required=True, help="input markdown file"
    )
    parser.add_argument(
        "--output", "-o", type=str, default="converted.html", help="output HTML file"
    )

    args = parser.parse_args()

    html_doc = open(args.output, "w")
    generated_html = (
        "<!DOCTYPE html>"
        + "<!--Converted via md-to-html-->"
        + "<html><head></head><body>"
    )

    with open(args.input) as f:
        content = f.readlines()
        for line in content:
            generated_html += mistune.markdown(line)

    generated_html += "</body></html>"

    # make BeautifulSoup
    soup = bs(generated_html, "html.parser")
    # prettify the html
    prettyHTML = soup.prettify()
    # write to the html doc
    html_doc.write(prettyHTML)


if __name__ == "__main__":
    main()



from setuptools import setup

# Should match git tag
VERSION = '0.5.0'


def readme():
    with open("README.md") as f:
        return f.read()


with open("requirements.txt") as file:
    REQUIRED_MODULES = [line.strip() for line in file]

with open("requirements-dev.txt") as file:
    DEVELOPMENT_MODULES = [line.strip() for line in file]


setup(
    name="md-to-html",
    version=VERSION,
    description="Python module for converting Markdown to HTML",
    long_description_content_type="text/markdown",
    long_description=readme(),
    keywords="markdown to html",
    url="https://github.com/AumitLeon/markdown_html_converter",
    author="Aumit Leon",
    author_email="aumitleon@gmail.com",
    packages=["src"],
    install_requires=REQUIRED_MODULES,
    extras_require={"dev": DEVELOPMENT_MODULES},
    entry_points={"console_scripts": ["md-to-html=src.converter:main"],},
    include_package_data=True,
)
